Use Case:  Search site for information
======================================

Actor
-----

Site Visitor

Overview
--------

Procedure
---------

1. Select the "Search" link from the masthead of any page. The system will
   display a form allowing you to specify the criteria for your search:

   **Full text search** --
     enter one or more words you expect to find in the "searchable text" of
     your content (searchable text normally consists of the textual content,
     if any, plus the title and description).

   **Title** --
      Enter one or more words you expecte to find in the Title of
      the content.

   **Subject** --
     Select one or more keywords from the available seletion
     box.

   **Description** --
     Enter one or more words you expecte to find in the Description of the
     content.

   **Find new items since...** --
     Select one of the options which corrsponds to the range of time in which
     objects were created.

   **Item Type** --
     Select one or more content types from the seletion box.

   **Creator** --
     Enter the user ID of the user who created the content.

   Enter your search criteria and select the search button.

2. The system will return a results page listing the first twenty matching
   objects. For each matching item, the results page displays the Title, the
   Description, and the "last modified" date; the Title is also a link to the
   object.

Alternatives
------------

1. Enter one or more "full text" search words in the "quick search" form in
   the masthead of any page. Click the "go" button. Continue with step #3 above.
